The CRSD 1.0 Reference Geometry object
======================================

.. automodule:: sarpy.io.received.crsd1_elements.ReferenceGeometry
    :members:
    :show-inheritance:
    :inherited-members:
